Authors
=======

This file contains the list of people involved in the development
of pytest_repeater along its history.

- Frank T (http://stackoverflow.com/users/1812727/frank-t)
- Tomasz Karbownicki (http://stackoverflow.com/users/692712/tomasz-karbownicki)
